# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
TProviderInterface = TypeVar("TProviderInterface")

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces

class AcamlLoadingErrorLog(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlLoadingErrorLog
):  # Class
    def __init__(self) -> None: ...

    FailedAcamls: Dict[str, str]  # readonly

    def AddState(self, storagePath: str, message: str) -> None: ...

class AcamlLoadingState(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AlreadyLoaded: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlLoadingState
    ) = ...  # static # readonly
    Failed: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlLoadingState
    ) = ...  # static # readonly
    NoError: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlLoadingState
    ) = ...  # static # readonly

class AcamlParam(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Acquisition: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlParam
    ) = ...  # static # readonly
    DataAnalysis: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlParam
    ) = ...  # static # readonly
    Identity: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlParam
    ) = ...  # static # readonly

class AcamlSection(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    All: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlSection
    ) = ...  # static # readonly
    MeasData: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlSection
    ) = ...  # static # readonly
    Result: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlSection
    ) = ...  # static # readonly
    Setup: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlSection
    ) = ...  # static # readonly

class DataAlreadyLoadedException(
    System.Runtime.InteropServices._Exception,
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataLoadingException,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class DataChangeLevel(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Compound: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly
    Global: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly
    Injection: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly
    Method: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly
    Peak: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly
    ResultSet: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly
    Sample: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly
    Signal: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataChangeLevel
    ) = ...  # static # readonly

class DataChecksumException(
    System.Runtime.InteropServices._Exception,
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.DataLoadingException,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class DataLoadingException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class DataUpdateException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class IAcamlBusinessRule(object):  # Interface
    Messages: Iterable[str]  # readonly
    OrderNumber: int  # readonly
    ThrowIfFailed: bool  # readonly

    def Apply(
        self,
        storageFileAccess: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class IAcamlFix(object):  # Interface
    OrderNumber: int  # readonly

    def NeedsFix(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...
    def Apply(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
    ) -> bool: ...

class IAcamlLoadingErrorLog(object):  # Interface
    FailedAcamls: Dict[str, str]  # readonly

class IAcamlReader(System.IDisposable):  # Interface
    DocId: System.Guid  # readonly
    IsPrefetchLockEnabled: bool  # readonly

    def MergeInjectionAcamls(
        self, injectionMeasDataIds: Iterable[System.Guid] = ...
    ) -> None: ...
    def EndInjectionAcamlPrefetching(self) -> None: ...
    def LoadSequenceAcaml(self, acamlStream: System.IO.Stream) -> None: ...
    def GetFinalizedAcaml(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        documentStoragePath: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML: ...
    def PrefetchInjectionAcaml(
        self,
        reference: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IInjectionAcamlReference,
        acamlStream: System.IO.Stream,
    ) -> None: ...
    def CreatePrefetchLock(self) -> System.IDisposable: ...
    def GetInjectionReferences(
        self,
    ) -> List[
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IInjectionAcamlReference
    ]: ...
    def BeginInjectionAcamlPrefetching(self) -> None: ...

class IAcamlReaderWriter(object):  # Interface
    EnforceAcamlBusinessRules: bool
    PrepareForDataModification: bool
    ValidateChecksumOnLoad: bool
    ValidateChecksumOnSave: bool
    ValidateSchemaOnLoad: bool
    ValidateSchemaOnSave: bool

    def CreateReader(
        self,
    ) -> (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlReader
    ): ...
    @overload
    def LoadAcamlMetadataAsync(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        cancellationToken: System.Threading.CancellationToken,
        createIfMissing: bool = ...,
    ) -> System.Threading.Tasks.Task[
        Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
        ]
    ]: ...
    @overload
    def LoadAcamlMetadataAsync(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        cancellationToken: System.Threading.CancellationToken,
        createIfMissing: bool = ...,
    ) -> System.Threading.Tasks.Task[
        Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
        ]
    ]: ...
    @overload
    def LoadAcamlMetadataAsync(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        paths: Iterable[str],
        cancellationToken: System.Threading.CancellationToken,
        createIfMissing: bool = ...,
    ) -> System.Threading.Tasks.Task[
        Dict[
            str,
            Iterable[
                Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
            ],
        ]
    ]: ...
    def CreateWriter(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
        fileName: str,
        saveOnlyChangedData: bool = ...,
        updateMetadata: bool = ...,
    ) -> (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlWriter
    ): ...
    @overload
    def LoadAcamlMetadata(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        createIfMissing: bool = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
    ]: ...
    @overload
    def LoadAcamlMetadata(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        path: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        createIfMissing: bool = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
    ]: ...
    @overload
    def LoadAcamlMetadata(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        paths: Iterable[str],
        createIfMissing: bool = ...,
    ) -> Dict[
        str,
        Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
        ],
    ]: ...

class IAcamlSignalLoader(object):  # Interface
    def ExtractChromatograms(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        signalMetaDataAndParameters: Dict[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters,
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        ],
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreType.IExtractedSignalDataContainer[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
        ]
    ]: ...
    def LoadInstrumentTrace(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def LoadReferenceChromatogram(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        path: str,
        traceId: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def GetSignalInformation(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISignalInformation: ...
    def LoadChromatogram(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def ReadGenericAnalyticalResultData(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        genericAnalyticalResultDataInfo: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IGenericAnalyticalResultDataInfo,
    ) -> List[int]: ...
    def ReadGenericAnalyticalResultDataInfo(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionMeasDataType,
    ) -> Sequence[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IGenericAnalyticalResultDataInfo
    ]: ...
    def ExtractChromatogram(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        metadataOfSignalToExtract: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        chromatogramExtractionParameters: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionParameters,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def TriggerSignalPrefetching(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        injectionOrder: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.AcamlInjectionId
        ],
        currentIndex: int,
    ) -> None: ...
    def UnloadSignalFromCache(
        self,
        docId: System.Guid,
        signalType: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> None: ...
    def ExtractSpectra(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        signalMetaDataAndParameters: Dict[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters,
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        ],
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreType.IExtractedSignalDataContainer[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData
        ]
    ]: ...
    def LoadSpectra(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData: ...
    def ExtractSpectrum(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        docId: System.Guid,
        spectra: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        metadataOfSignalToExtract: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType,
        spectrumExtractionParameters: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExtractionParameters,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...

class IAcamlStreamProxy(object):  # Interface
    FileBasedStream: System.IO.Stream  # readonly
    TempFilePath: str  # readonly

    @overload
    def Read(
        self,
        fileAccess: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
        path: str,
    ) -> bool: ...
    @overload
    def Read(self, stream: System.IO.Stream) -> bool: ...
    def Dispose(self) -> None: ...

class IAcamlWriter(System.IDisposable):  # Interface
    InjectionAcamlsParts: Dict[
        System.Guid,
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IInjectionAcamlPart,
    ]  # readonly
    SequenceAcamlStream: System.IO.Stream  # readonly

    def SetSequenceAcamlSaved(self) -> None: ...
    def ClearChangesOnSaved(self) -> None: ...

class IDataProviderFactory(object):  # Interface
    @overload
    def GetProviderSet(
        self, docId: System.Guid
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
    ]: ...
    @overload
    def GetProviderSet(
        self, acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
    ]: ...
    @overload
    def GetProvider(self, docId: System.Guid) -> TProviderInterface: ...
    @overload
    def GetProvider(
        self, acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML
    ) -> TProviderInterface: ...
    def IsRegistered(
        self, acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML
    ) -> bool: ...
    def RegisterAcaml(
        self,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
        prepareForWriteAccess: bool,
    ) -> bool: ...

class IGlobalDataProvider(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
):  # Interface
    AgilentApplication: Optional[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.AgilentApplicationEnum
    ]
    DocumentInfo: (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IDocInfoType
    )  # readonly
    InjectionsMetadata: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
    ]  # readonly
    Methods: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType
    ]  # readonly

    @overload
    def AddMethodDefinition(
        self,
        methodDefinition: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType,
    ) -> None: ...
    @overload
    def AddMethodDefinition(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        description: str,
        lastModifiedDate: System.DateTime,
        dataFileReferencePath: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType: ...
    def RemoveCustomCalculationResult(
        self,
        customCalcEmbeddedResult: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICustomCalcEmbeddedResultType,
    ) -> None: ...
    def RemoveUnusedMethodDefinitions(self) -> Iterable[System.Guid]: ...
    def RemoveUnusedCustomCalculationResults(self) -> None: ...
    def UpdateMethodDefinition(
        self,
        methodDefinition: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType,
    ) -> None: ...
    def RefreshInjectionsMetadata(
        self, injectionIds: Iterable[System.Guid]
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
    ]: ...
    def RemoveCustomCalculationResults(self, parentId: System.Guid) -> None: ...
    @overload
    def GetMethodDefinition(
        self, methodId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType: ...
    @overload
    def GetMethodDefinition(
        self,
        nonIdentParamBase: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.INonIdentParamBaseType,
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType: ...
    @overload
    def GetMethodDefinition(
        self, dataFileReferencePath: str
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType: ...
    def ClearMethodDefinitions(self) -> None: ...
    def GetInjectionMetadata(
        self, injectionId: System.Guid
    ) -> (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
    ): ...
    def PerformExactFulltextSearch(
        self, keywords: List[str]
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.AcamlInjectionId
    ]: ...
    def PerformFuzzyFulltextSearch(
        self, keywords: List[str]
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.AcamlInjectionId
    ]: ...
    def AddCustomCalculationResult(
        self,
        customCalcEmbeddedResultType: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICustomCalcEmbeddedResultType,
    ) -> None: ...
    def ClearCustomCalculationResults(self) -> None: ...
    def RemoveMethodDefinition(
        self,
        methodDefinition: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType,
    ) -> None: ...
    def SetNewDocumentId(self) -> None: ...
    def ApplyMetadata(
        self,
        injectionMetadata: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData,
    ) -> None: ...

class IInjectionAcamlPart(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IInjectionAcamlReference
):  # Interface
    InjectionAcamlStream: System.IO.Stream  # readonly

    def SetSaved(self) -> None: ...

class IInjectionAcamlReference(object):  # Interface
    InjectionFileName: str  # readonly
    InjectionMeasDataId: System.Guid  # readonly

class IInjectionsProvider(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
):  # Interface
    Injections: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer
    ]  # readonly
    def __getitem__(
        self, injectionId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer: ...
    MeasData: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionMeasDataType
    ]  # readonly
    Peaks: Dict[
        System.Guid, Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType
    ]  # readonly
    Results: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionResultType
    ]  # readonly

    def AddCalibrationStandardAmount(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        istdAmount: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType,
    ) -> None: ...
    def LinkSamplePurityToSignal(
        self,
        samplePurity: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISamplePurityContainer,
        signalId: System.Guid,
    ) -> None: ...
    @overload
    def GetIdentifiedPeaks(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
        doLookupCalibCurves: bool,
        calibPeakRoles: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CalibPeakRoleEnum = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IIdentifiedPeakAggregation
    ]: ...
    @overload
    def GetIdentifiedPeaks(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
        signalFilter: System.Predicate[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType
        ],
        doLookupCalibCurves: bool,
        calibPeakRoles: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CalibPeakRoleEnum = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IIdentifiedPeakAggregation
    ]: ...
    def UnlinkInjectionCompoundFromCalibrationCurve(
        self,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
    ) -> None: ...
    def LinkSamplePurityToPeak(
        self,
        samplePurity: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISamplePurityContainer,
        peakId: System.Guid,
    ) -> None: ...
    def GetInjection(
        self, injectionMeasDataId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer: ...
    def GetInjectionCompounds(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer = ...,
        filterPredicate: System.Predicate[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType
        ] = ...,
        ignoreUnknowns: bool = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType
    ]: ...
    def RemoveInjectionCompound(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
    ) -> None: ...
    def GetCalibrationCurvesByInjectionCompound(
        self,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType: ...
    def AddRunType(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        runType: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IRunTypeAndReplicationType,
    ) -> None: ...
    def UnlinkAllSeparationMediaFromInjection(
        self,
        injectionContainer: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def UnlinkSamplePurityFromSignal(
        self,
        samplePurity: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISamplePurityContainer,
    ) -> None: ...
    def AddMultipliers(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        multipliers: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
        ],
    ) -> None: ...
    def UnlinkAcqMethodDefinition(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def AddInternalStandardAmount(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        istdAmount: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType,
    ) -> None: ...
    def LinkAcqMethodDefinition(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        methodDefinition: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType,
    ) -> None: ...
    def AddOverriddenMethodParameters(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        methodParameter: Iterable[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodParameterType
        ],
    ) -> None: ...
    def GetInjectionCompoundsByPeak(
        self,
        peakId: System.Guid,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        calibPeakRoles: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CalibPeakRoleEnum = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType
    ]: ...
    def ClearDilutionFactors(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def CreateAndLinkDaMethodDefinition(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        methodPath: str,
        description: str,
        lastModifiedDate: System.DateTime,
    ) -> None: ...
    @overload
    def GetParentInjectionOfSignal(
        self, signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer: ...
    @overload
    def GetParentInjectionOfSignal(
        self, signalId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer: ...
    def AddSamplePurityResult(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        samplePurity: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISamplePurityContainer,
    ) -> None: ...
    def UnlinkSamplePurityFromPeak(
        self,
        samplePurity: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISamplePurityContainer,
    ) -> None: ...
    def GetParentSample(
        self, injectionMeasDataId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer: ...
    def ClearMultipliers(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def AddDilutionFactors(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        dilutionFactors: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
        ],
    ) -> None: ...
    def ClearOverriddenMethodParameters(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def ClearCalibrationStandardAmounts(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def GetPrimaryDataElementName(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> str: ...
    @overload
    def GetSignalsProvider(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.ISignalsProvider
    ): ...
    @overload
    def GetSignalsProvider(
        self, signalId: System.Guid
    ) -> (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.ISignalsProvider
    ): ...
    def GetCalibrationCurvesByPeak(
        self,
        peakId: System.Guid,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        calibPeakRoles: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CalibPeakRoleEnum = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType
    ]: ...
    def UpdateInjectionCompound(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
    ) -> None: ...
    def AddInjectionCompound(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
    ) -> None: ...
    def GetOverriddenMethodParameters(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodParameterType
    ]: ...
    def LinkDaMethodDefinition(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        methodDefinition: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IMethodType,
    ) -> None: ...
    def ClearInjectionCompounds(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def AddInjectionCompounds(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
        injectionCompounds: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType
        ],
        clearExistingInjectionCompounds: bool = ...,
    ) -> None: ...
    @overload
    def UnlinkIdentifiedPeakFromCalibrationCurve(
        self,
        identifiedPeak: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IIdentifiedPeakAggregation,
    ) -> None: ...
    @overload
    def UnlinkIdentifiedPeakFromCalibrationCurve(
        self,
        peakRef: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakRefType,
    ) -> None: ...
    def ClearInternalStandardAmounts(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def GetPeaksAndCompoundsAtAGlance(
        self, injectionIds: Iterable[System.Guid]
    ) -> Dict[
        str,
        Dict[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.AcamlInjectionId,
            System.Tuple[
                Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
                Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType,
                Dict[str, str],
            ],
        ],
    ]: ...
    def GetDilutionFactors(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
    ]: ...
    def ClearRunTypes(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def GetMultipliers(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
    ]: ...
    def GetRunTypes(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IRunTypeAndReplicationType
    ]: ...
    @overload
    def LinkCalibrationCurveToIdentifiedPeak(
        self,
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
        identifiedPeak: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IIdentifiedPeakAggregation,
    ) -> None: ...
    @overload
    def LinkCalibrationCurveToIdentifiedPeak(
        self,
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
        peakRef: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakRefType,
    ) -> None: ...
    def LinkCalibrationCurveToInjectionCompound(
        self,
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
        injectionCompound: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionCompoundType,
    ) -> None: ...
    @overload
    def LinkSeparationMediumToInjection(
        self,
        separationMediumId: System.Guid,
        injectionContainer: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    @overload
    def LinkSeparationMediumToInjection(
        self,
        injectionSeparationMediumType: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionSeparationMediumType,
        injectionContainer: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def UnlinkDaMethodDefinition(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def UnlinkSeparationMediumFromInjection(
        self,
        separationMediumId: System.Guid,
        injectionContainer: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> None: ...
    def GetInternalStandardAmounts(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType
    ]: ...
    def GetCalibrationStandardAmounts(
        self,
        injection: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType
    ]: ...

class IProvider(object):  # Interface
    CurrentUserName: str
    DocId: System.Guid  # readonly

class IProviderLookupCache(object):  # Interface
    DocId: System.Guid  # readonly

    def DirtyDictionaryCount(self) -> int: ...
    def Reset(self) -> None: ...
    def Clear(self) -> None: ...
    def HasDirtyDictionaries(self) -> bool: ...

class IResourcesProvider(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
):  # Interface
    CalibrationCurves: Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType
    ]  # readonly
    Instruments: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInstrumentType
    ]  # readonly
    Resources: (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IResourcesType
    )  # readonly
    SeparationMedia: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISeparationMediumType
    ]  # readonly

    def AddCalibrationCurve(
        self,
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
    ) -> None: ...
    def RemoveUnusedInstruments(self) -> Iterable[System.Guid]: ...
    def AddSeparationMedium(
        self,
        separationMedium: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISeparationMediumType,
    ) -> None: ...
    def GetCalibrationCurve(
        self, calibrationCurveId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType: ...
    def RemoveInstrument(
        self,
        instrument: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInstrumentType,
    ) -> None: ...
    def UpdateCalibrationCurve(
        self,
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
    ) -> None: ...
    def GetSeparationMedium(
        self, separationMediumId: System.Guid
    ) -> (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISeparationMediumType
    ): ...
    def RemoveCalibrationCurve(
        self,
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
    ) -> None: ...
    def RemoveUnusedCalibrationCurves(self) -> Iterable[System.Guid]: ...
    def AddInstrument(
        self,
        instrument: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInstrumentType,
    ) -> None: ...
    def RemoveSeparationMedium(
        self,
        separationMedium: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISeparationMediumType,
    ) -> None: ...
    def RemoveUnusedSeparationMedia(self) -> Iterable[System.Guid]: ...

class ISampleContextProvider(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
):  # Interface
    ContentType: (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.SampleContextTypeEnum
    )  # readonly
    Instruments: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInstrumentType
    ]  # readonly
    MeasData: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleMeasDataContextType
    ]  # readonly
    PackagingMode: (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.PackagingModeEnum
    )  # readonly
    SampleContext: (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContextContainer
    )  # readonly
    Setups: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleSetupContextType
    ]  # readonly

    def UnlinkAllInstrumentsFromSampleContext(self) -> None: ...
    def UnlinkInstrumentFromSampleContext(self, instrumentId: System.Guid) -> None: ...
    def LinkInstrumentToSampleContext(
        self,
        instrumentId: System.Guid,
        acamlSection: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlSection,
    ) -> None: ...

class ISamplesProvider(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
):  # Interface
    def __getitem__(
        self, sampleId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer: ...
    MeasData: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleMeasDataType
    ]  # readonly
    Samples: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer
    ]  # readonly
    Setups: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleSetupType
    ]  # readonly

    def AddCalibrationStandardAmount(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        istdAmount: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType,
    ) -> None: ...
    def AddSamplePuritySetup(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        samplePurity: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISamplePurityContainer,
    ) -> None: ...
    def UnlinkInstrument(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> None: ...
    def RemoveSamplePurity(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        samplePurityId: System.Guid,
    ) -> None: ...
    def GetSample(
        self, sampleSetupId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer: ...
    def AddRunType(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        runType: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IRunTypeAndReplicationType,
    ) -> None: ...
    def AddMultipliers(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        multipliers: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
        ],
    ) -> None: ...
    def AddInternalStandardAmount(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        istdAmount: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType,
    ) -> None: ...
    def ClearDilutionFactors(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> None: ...
    def ClearMultipliers(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> None: ...
    def AddDilutionFactors(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        dilutionFactors: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
        ],
    ) -> None: ...
    def ClearCalibrationStandardAmounts(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> None: ...
    def LinkInstrumentToSample(
        self,
        instrumentId: System.Guid,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
        acamlSection: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.AcamlSection,
    ) -> None: ...
    def GetInstrument(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInstrumentType: ...
    def GetInjections(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer
    ]: ...
    def ClearInternalStandardAmounts(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> None: ...
    def GetDilutionFactors(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
    ]: ...
    def ClearRunTypes(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> None: ...
    def GetRunTypes(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IRunTypeAndReplicationType
    ]: ...
    def GetMultipliers(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ICorrectionFactorType
    ]: ...
    def GetSamplePurities(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISamplePurityContainer
    ]: ...
    def ClearSamplePurities(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> None: ...
    def GetInternalStandardAmounts(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType
    ]: ...
    def GetCalibrationStandardAmounts(
        self,
        sample: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISampleContainer,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IStandardCompoundAmountType
    ]: ...

class ISignalsProvider(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IProvider
):  # Interface
    ParentInjection: (
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionContainer
    )  # readonly
    Peaks: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType
    ]  # readonly
    SignalMeasData: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType
    ]  # readonly
    SignalResults: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IInjectionSignalResultType
    ]  # readonly
    Signals: Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer
    ]  # readonly

    def AddNoisePeriods(
        self,
        noisePeriods: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.INoisePeriodType
        ],
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...
    def ClearNoisePeriods(
        self,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...
    def AddPeak(
        self,
        peak: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...
    def UnlinkAllSignalsFromPeak(
        self, peak: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType
    ) -> None: ...
    def LinkSignalToPeak(
        self,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
        peak: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType,
    ) -> None: ...
    def ClearPeakDeletions(
        self,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...
    def GetSignalIdsByType(
        self,
        typeFilters: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.SignalTypeFilters,
    ) -> Iterable[System.Guid]: ...
    def GetSignalsByType(
        self,
        signalTypeFilters: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.SignalTypeFilters = ...,
    ) -> Iterable[
        Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer
    ]: ...
    def ClearSignals(self) -> None: ...
    def ClearPeaks(
        self,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...
    @overload
    def GetSignal(
        self, signalId: System.Guid
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer: ...
    @overload
    def GetSignal(
        self, signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalType
    ) -> Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer: ...
    @overload
    def GetRawChromData(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        signalId: System.Guid,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    @overload
    def GetRawChromData(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        signalName: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    def AddNoisePeriod(
        self,
        noisePeriod: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.INoisePeriodType,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...
    def AddPeaks(
        self,
        peaks: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType
        ],
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
        clearExistingPeaks: bool = ...,
    ) -> None: ...
    @overload
    def GetSpectraData(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        signalId: System.Guid,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData: ...
    @overload
    def GetSpectraData(
        self,
        storageProvider: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
        workAreaName: str,
        signalName: str,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData: ...
    def UpdatePeak(
        self,
        peak: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...
    def UnlinkSignalFromPeak(
        self,
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
        peak: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IPeakType,
    ) -> None: ...
    def AddPeakDeletions(
        self,
        peakDeletions: Iterable[
            Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.PeakDeletionType
        ],
        signal: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.ISignalContainer,
    ) -> None: ...

class SignalTypeFilters(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Chromatograms: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.SignalTypeFilters
    ) = ...  # static # readonly
    ExtractedChromatograms: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.SignalTypeFilters
    ) = ...  # static # readonly
    ExtractedSpectra: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.SignalTypeFilters
    ) = ...  # static # readonly
    InstrumentCurve: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.SignalTypeFilters
    ) = ...  # static # readonly
    Spectra: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.SignalTypeFilters
    ) = ...  # static # readonly

class Versions:  # Class
    RawDataReaderPluginVersion: int = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataSource.Quant.QuickReport

class QuickReportDataSource(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.DataSource.IDataSource
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
        dataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator,
        renderGraphics: System.Action[
            Agilent.MassSpectrometry.GUI.Plot.IGraphics, float, float, float, float, str
        ],
    ) -> None: ...
    def DrawGraphics(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        name: str,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    def GetFieldCaption(self, dataName: str, fieldName: str) -> str: ...
    def Select(
        self,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        dataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding,
    ) -> List[Any]: ...
    def LocalizeFieldValue(self, dataName: str, fieldName: str, value_: Any) -> str: ...
    def GetFieldFormat(self, dataName: str, fieldName: str) -> str: ...
    def Dispose(self) -> None: ...

class QuickReportDataSourceDesigner(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceDesigner
):  # Class
    def __init__(self) -> None: ...

    DataSourceType: System.Type  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly

    def GetFieldNames(self, dataName: str) -> List[str]: ...
    def GetDataNames(self) -> List[str]: ...
    def GetParameterCategoryDisplayName(self, category: str) -> str: ...
    def GetParameterDisplayName(self, name: str) -> str: ...
    def Dispose(self) -> None: ...
    def GetCustomCommandGroups(
        self, application: Agilent.MassHunter.ReportBuilder.Application.IApplication
    ) -> List[Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommandGroup]: ...
    def GetCustomUI(self) -> T: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Extract

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class CommandLine:  # Class
    def __init__(self) -> None: ...

    Culture: str
    DeploymentFile: str
    Destination: str
    Help: bool
    Silent: bool
    Uninstall: bool

class MainViewModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self) -> None: ...

    CommandBrowseDeploymentFilePath: System.Windows.Input.ICommand  # readonly
    CommandBrowseDestinationPath: System.Windows.Input.ICommand  # readonly
    CommandExtract: System.Windows.Input.ICommand  # readonly
    DeploymentFilePath: str
    DestinationPath: str
    Window: Agilent.MassHunter.Quantitative.Startup.Extract.MainWindow  # readonly

    def DoExtract(self) -> None: ...
    def Uninstall(self) -> None: ...

class MainWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Utils import CultureItem
from .ViewModel import (
    IControlPanelViewModel,
    IGeneralSettingsViewModel,
    ITask,
    ITaskGroup,
    TaskViewModelBase,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.General

class DemoTask(ITask):  # Class
    def __init__(self, title: str) -> None: ...

    Content: System.Windows.UIElement  # readonly
    IsEnabled: bool  # readonly
    Title: str  # readonly

    def Leaving(self) -> bool: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...
    def Activate(self) -> None: ...

class EditStartupTaskGroup(System.Windows.DependencyObject, ITaskGroup):  # Class
    def __init__(self, model: IControlPanelViewModel) -> None: ...

    IsEnabledProperty: System.Windows.DependencyProperty  # static

    IsEnabled: bool  # readonly
    Tasks: List[ITask]  # readonly
    Title: str  # readonly

class GeneralSettingsView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class GeneralSettingsViewModel(
    TaskViewModelBase, IGeneralSettingsViewModel, ITask
):  # Class
    def __init__(self, rootModel: IControlPanelViewModel) -> None: ...

    AllowFlexibleDockingProperty: System.Windows.DependencyProperty  # static
    DisplayNameHintProperty: System.Windows.DependencyProperty  # static
    DisplayNameProperty: System.Windows.DependencyProperty  # static
    InstrumentTypeProperty: System.Windows.DependencyProperty  # static
    IsEnabledProperty: System.Windows.DependencyProperty  # static
    SelectedLanguageProperty: System.Windows.DependencyProperty  # static

    AllowFlexibleDocking: bool
    Content: System.Windows.UIElement  # readonly
    DisplayName: str
    DisplayNameHint: str
    InstrumentItems: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.EnumItem[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
        ]
    ]  # readonly
    InstrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    IsEnabled: bool  # readonly
    Languages: List[CultureItem]  # readonly
    SelectedLanguage: str
    Title: str  # readonly

    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def IsDirty(self) -> bool: ...
    def Leaving(self) -> bool: ...
    def Activate(self) -> None: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...

class ToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Remoting
from .HeatMap import HeatMapControl, IHeatMapData
from .PlotControl import IAxisContainer, IPlotSeries, PlotMode

# Stubs for namespace: Agilent.MassHunter.Quantitative.Profile3DView

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class CommandLine:  # Class
    def __init__(self) -> None: ...

    MZ: float
    RetentionTime: float
    Sample: str
    Singleton: bool

class DelegateCommand(System.Windows.Input.ICommand):  # Class
    def __init__(
        self, exec: System.Action, canexec: System.Func[Any, bool]
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class HeatMapAdorner(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Documents.Adorner,
):  # Class
    def __init__(
        self, c: Agilent.MassHunter.Quantitative.Profile3DView.HeatMapControl
    ) -> None: ...

class HeatMapControl(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IInputElement,
    IAxisContainer,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IFrameworkInputElement,
):  # Class
    def __init__(self) -> None: ...

class HeatMapData(IHeatMapData):  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.Profile3DView.Model
    ) -> None: ...

    MaxValue: float
    MaxX: float
    MaxY: float
    MinValue: float
    MinX: float
    MinY: float
    XCount: int
    YCount: int

    def GetValue(self, x: int, y: int) -> float: ...

class HeatMapView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class HeatMapViewModel(System.Windows.DependencyObject):  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.Profile3DView.Model
    ) -> None: ...

    SelectedPointProperty: System.Windows.DependencyProperty  # static # readonly

    Model: Agilent.MassHunter.Quantitative.Profile3DView.Model  # readonly
    SelectedPoint: Optional[System.Windows.Point]

class LeftPanelControl(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class MainWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class Model(System.Windows.DependencyObject):  # Class
    def __init__(self) -> None: ...

    CountFormatProperty: System.Windows.DependencyProperty  # static # readonly
    CountRangeProperty: System.Windows.DependencyProperty  # static # readonly
    MZFormatProperty: System.Windows.DependencyProperty  # static # readonly
    MZProperty: System.Windows.DependencyProperty  # static # readonly
    MZRangeProperty: System.Windows.DependencyProperty  # static # readonly
    MaxCountProperty: System.Windows.DependencyProperty  # static # readonly
    MaxMZProperty: System.Windows.DependencyProperty  # static # readonly
    MaxRTProperty: System.Windows.DependencyProperty  # static # readonly
    MinCountProperty: System.Windows.DependencyProperty  # static # readonly
    MinMZProperty: System.Windows.DependencyProperty  # static # readonly
    MinRTProperty: System.Windows.DependencyProperty  # static # readonly
    PointCountProperty: System.Windows.DependencyProperty  # static # readonly
    RTFormatProperty: System.Windows.DependencyProperty  # static # readonly
    RTProperty: System.Windows.DependencyProperty  # static # readonly
    RTRangeProperty: System.Windows.DependencyProperty  # static # readonly
    RangeFactorProperty: System.Windows.DependencyProperty  # static # readonly
    SampleFileNameProperty: System.Windows.DependencyProperty  # static # readonly
    ScanCountProperty: System.Windows.DependencyProperty  # static # readonly
    SelectedViewIndexProperty: System.Windows.DependencyProperty  # static # readonly
    ZValuesProperty: System.Windows.DependencyProperty  # static # readonly

    ChangeRange: System.Windows.Input.ICommand  # readonly
    CountFormat: str
    CountRange: str  # readonly
    HeatMapViewModel: (
        Agilent.MassHunter.Quantitative.Profile3DView.HeatMapViewModel
    )  # readonly
    MZ: Optional[float]
    MZFormat: str
    MZRange: str  # readonly
    MaxCount: Optional[float]
    MaxMZ: Optional[float]
    MaxRT: Optional[float]
    MinCount: Optional[float]
    MinMZ: Optional[float]
    MinRT: Optional[float]
    PointCount: int
    Profile3DViewModel: (
        Agilent.MassHunter.Quantitative.Profile3DView.Profile3DViewModel
    )  # readonly
    RT: Optional[float]
    RTFormat: str
    RTRange: str  # readonly
    RangeFactor: int
    SampleFileName: str
    ScanCount: int
    SelectedViewIndex: int
    ZValues: List[List[float]]

    def Open(self, samplePath: str, mz: float, rt: float) -> None: ...
    def Clear(self) -> None: ...
    def GetChrom(self, x: int) -> List[float]: ...

class PlotControl(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.Control,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IFrameworkInputElement,
):  # Class
    def __init__(self) -> None: ...

    InternalMargin: System.Windows.Thickness
    Series: IPlotSeries
    Vertical: bool

class PlotSeriesArr(IPlotSeries):  # Class
    def __init__(self, data: List[float], minX: float, maxX: float) -> None: ...

    Count: int  # readonly
    Pen: System.Windows.Media.Pen  # readonly
    PlotMode: PlotMode  # readonly
    Visible: bool  # readonly

    def GetPoint(self, index: int, x: float, y: float) -> None: ...

class Profile3DControl(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    def Clear(self) -> None: ...
    def InitFeature(
        self,
        minx: float,
        maxx: float,
        miny: float,
        maxy: float,
        nx: int,
        ny: int,
        zvalues: List[List[float]],
    ) -> None: ...
    def LoadLogFile(self, file: str) -> None: ...

class Profile3DException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, msg: str) -> None: ...
    @overload
    def __init__(self, msg: str, inner: System.Exception) -> None: ...

class Profile3DViewModel(System.Windows.DependencyObject):  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.Profile3DView.Model
    ) -> None: ...

    Is3DViewActiveProperty: System.Windows.DependencyProperty  # static # readonly
    MZOffsetProperty: System.Windows.DependencyProperty  # static # readonly
    MZScaleFactorProperty: System.Windows.DependencyProperty  # static # readonly
    RTOffsetProperty: System.Windows.DependencyProperty  # static # readonly
    RTScaleFactorProperty: System.Windows.DependencyProperty  # static # readonly
    ScaleFactorProperty: System.Windows.DependencyProperty  # static # readonly
    ViewportRotationCounterProperty: (
        System.Windows.DependencyProperty
    )  # static # readonly
    ZOffsetProperty: System.Windows.DependencyProperty  # static # readonly
    ZScaleFactorProperty: System.Windows.DependencyProperty  # static # readonly

    ChromatographicView: System.Windows.Input.ICommand  # readonly
    HeatMapView: System.Windows.Input.ICommand  # readonly
    Is3DViewActive: bool  # readonly
    MZOffset: float
    MZScaleFactor: float
    Model: Agilent.MassHunter.Quantitative.Profile3DView.Model  # readonly
    RTOffset: float
    RTScaleFactor: float
    ResetScale: System.Windows.Input.ICommand  # readonly
    ResetViewport: System.Windows.Input.ICommand  # readonly
    ScaleFactor: float
    SpectralView: System.Windows.Input.ICommand  # readonly
    ViewportRotationCounter: int
    ViewportRotationX: float
    ViewportRotationY: float
    ViewportRotationZ: float
    ZOffset: float
    ZScaleFactor: float

class RangeFactorWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.Profile3DView.Model
    ) -> None: ...
    def InitializeComponent(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import MassIsotopeChoice, SpectralPeak
from .IsotopePatternCalculator import (
    IIsotopePattern,
    IsotopePatternCalculatorParameters,
)
from .Mathematics import RangeDouble, RangeInt
from .Mfe import IsotopeCharacter

# Stubs for namespace: Biochemistry

class AminoAcids(Biochemistry.SuperAtomSet):  # Class
    def __init__(self) -> None: ...

class ChargeState:  # Struct
    def __init__(self, z: int, type: Biochemistry.ChargeState.Type) -> None: ...

    ChargeType: Biochemistry.ChargeState.Type
    Z: int

    ChargeCount: int

    def GetIonMass(self, neutralMass: float) -> float: ...
    def MZ2NeutrolMass(self, mz: float) -> float: ...

    # Nested Types

    class Type(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
        Electron: Biochemistry.ChargeState.Type = ...  # static # readonly
        Proton: Biochemistry.ChargeState.Type = ...  # static # readonly
        Unknown: Biochemistry.ChargeState.Type = ...  # static # readonly

class CompositionModel:  # Class
    A2DominatingMass: float  # readonly
    CarbonMassFraction: float  # readonly
    CarbonMassFractionRange: RangeDouble  # readonly

    def CalculateIsotopePattern(self, m0: float) -> List[SpectralPeak]: ...
    def GetIsotopeMassOffset(self, isotopeIndex: int, m0: float) -> float: ...
    def GetIsotopePattern(
        self, m0: float, userParameter: IsotopePatternCalculatorParameters
    ) -> IIsotopePattern: ...
    def AllowsMass(self, mass: float) -> bool: ...
    @staticmethod
    def CreateModel(
        isotopeCharacter: IsotopeCharacter,
    ) -> Biochemistry.CompositionModel: ...
    def GetAverageMassFromLowestMass(self, lowestMass: float) -> float: ...
    def GetCarbonRange(self, mass: float) -> RangeInt: ...
    def GetMaxMissingLeadingPeakAllowrance(self, mass: float) -> int: ...

class CompoundMass:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def PossibleAsIon(mass: float) -> bool: ...
    @staticmethod
    def PossibleAsNeutralLoss(mass: float) -> bool: ...

class Constants:  # Class
    def __init__(self) -> None: ...

    AverageIsotopeMassIncrement: float  # static # readonly
    ElectronMass: float  # static # readonly
    KIonMass: float  # static # readonly
    NaIonMass: float  # static # readonly
    ProtonMass: float  # static # readonly

class DoubleBondEquivalency:  # Class
    def __init__(self) -> None: ...
    def GetValue(self, element: str) -> float: ...

class ElementContentLimits:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def MaxN(compoundMass: float) -> float: ...
    @staticmethod
    def MaxS(compoundMass: float) -> float: ...
    @staticmethod
    def MaxCl(compoundMass: float) -> float: ...
    @staticmethod
    def MinHCount(compoundMass: float) -> int: ...
    @staticmethod
    def MinCCount(compoundMass: float) -> int: ...
    @staticmethod
    def MaxF(compoundMass: float) -> float: ...
    @staticmethod
    def MaxNa(compoundMass: float) -> float: ...
    @staticmethod
    def MaxC(compoundMass: float) -> float: ...
    @staticmethod
    def MaxBr(compoundMass: float) -> float: ...
    @staticmethod
    def MaxO(compoundMass: float) -> float: ...
    @staticmethod
    def MaxH(compoundMass: float) -> float: ...

class ElementMassCalculator:  # Class
    def __init__(self, massChoice: MassIsotopeChoice) -> None: ...
    def GetMass(self, symbol: str) -> float: ...

class ElementPickerControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    Elements: System.Collections.Generic.List[str]

class ElementProperty:  # Class
    AverageMass: int  # readonly
    ElementProperties: Dict[str, Biochemistry.ElementProperty]  # static # readonly
    ImplicitValence: bool  # readonly
    MetalCode: Biochemistry.ElementProperty.MetalStatus  # readonly

    def GetValences(self, z: int) -> List[int]: ...

    # Nested Types

    class MetalStatus(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Metal: Biochemistry.ElementProperty.MetalStatus = ...  # static # readonly
        Metal2: Biochemistry.ElementProperty.MetalStatus = ...  # static # readonly
        NonMetal: Biochemistry.ElementProperty.MetalStatus = ...  # static # readonly

class EmpiricalConstants:  # Class
    def __init__(self) -> None: ...

    MinCarbonWeightContent: float  # static # readonly
    MinCarbonWeightContentAveragine: float  # static # readonly

class GlycanModel(Biochemistry.CompositionModel):  # Class
    def __init__(self) -> None: ...

    A2DominatingMass: float  # readonly
    CarbonMassFractionRange: RangeDouble  # readonly

    def GetIsotopeMassOffset(self, isotopeIndex: int, m0: float) -> float: ...

class NaturalMolecule(Iterable[Any]):  # Class
    def __init__(self) -> None: ...

    AtomCount: int  # readonly
    CentroidMass: float  # readonly
    DoubleBondEquivalent: float  # readonly
    ElectronCount: int  # readonly
    Formula: str  # readonly
    LowestIsotopeMass: float  # readonly
    LowestIsotopeNominalMass: int  # readonly
    MonoisotopicMass: float  # readonly
    MonoisotopicNominalMass: int  # readonly
    RelativeDoubleBondEquivalent: float  # readonly

    def GetEnumerator(self) -> Iterator[Any]: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, another: Biochemistry.NaturalMolecule) -> bool: ...
    @overload
    def Add(self, another: Biochemistry.NaturalMolecule) -> None: ...
    @overload
    def Add(self, another: Biochemistry.NaturalMolecule, count: int) -> None: ...
    def GetAtomCountOf(self, atomicNumber: int) -> int: ...
    def IsSubsetOf(self, potentialParent: Biochemistry.NaturalMolecule) -> bool: ...
    @overload
    def AddElements(self, symbol: str, amount: int) -> None: ...
    @overload
    def AddElements(self, atomicNumber: int, amount: int) -> None: ...
    def GetHashCode(self) -> int: ...
    @staticmethod
    def Parse(formula: str) -> Biochemistry.NaturalMolecule: ...
    def Clone(self) -> Biochemistry.NaturalMolecule: ...

class RadioactiveIsotopes:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetMass(symbol: str, nucleonNumber: int, mass: float) -> bool: ...

class Ribonucleotides(Biochemistry.SuperAtomSet):  # Class
    def __init__(self) -> None: ...

class SuperAtomSet:  # Class
    def __init__(self) -> None: ...
    def GetElectronCount(self, symbol: str) -> int: ...
    def Contains(self, symbol: str) -> bool: ...
    def GetMass(self, symbol: str, massChoice: MassIsotopeChoice) -> float: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.ErrorReporting

class ErrorReportContentsForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, contents: str) -> None: ...

class ErrorReporter:  # Class
    @overload
    def __init__(
        self,
        appId: int,
        emailAddress: str,
        errorSource: str,
        exception: System.Exception,
    ) -> None: ...
    @overload
    def __init__(
        self, appId: int, emailAddress: str, errorSource: str, errorReport: str
    ) -> None: ...
    @overload
    def __init__(
        self,
        appId: int,
        emailAddress: str,
        errorSource: str,
        errorReport: str,
        contactInfo: str,
        exception: System.Exception,
    ) -> None: ...

    AppId: int  # readonly
    ContactInformation: str
    DestinationUrl: str  # readonly
    EmailAddress: str  # readonly
    EmailSubject: str
    ErrorReport: str
    ErrorSource: str
    ExceptionReport: str
    FileAttachments: System.Collections.Specialized.StringCollection  # readonly

    @overload
    def TestConnectionToDestinationUrl(self) -> bool: ...
    @overload
    def TestConnectionToDestinationUrl(self, millisecsTimeout: int) -> bool: ...
    @staticmethod
    def GetProcessModuleInformation() -> str: ...
    @staticmethod
    def GetProcessThreadInformation() -> str: ...
    def GenerateFullErrorReport(self) -> str: ...
    def AddAttachment(self, path: str) -> None: ...
    @staticmethod
    def GetPlatformInformation() -> str: ...
    @staticmethod
    def GetStackTraceReport(exception: System.Exception) -> str: ...
    @staticmethod
    def GetExceptionInformation(exception: System.Exception) -> str: ...
    @staticmethod
    def CreateExceptionReport(exception: System.Exception) -> str: ...
    def SendReport(self) -> None: ...
    def ShowErrorWindow(self) -> None: ...

class ErrorReporterForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self, errorReport: Agilent.MassSpectrometry.ErrorReporting.ErrorReporter
    ) -> None: ...

    BodyContentsLabel: System.Windows.Forms.Label  # readonly
    BodyTitleLabel: System.Windows.Forms.Label  # readonly
    ErrorReporter: Agilent.MassSpectrometry.ErrorReporting.ErrorReporter  # readonly
    HeaderLabel: System.Windows.Forms.Label  # readonly
    LogoPictureBox: System.Windows.Forms.PictureBox  # readonly
